<?php

/**
 * @file
 * Contains \Drupal\eayschart\Plugin\entity_embed\EntityEmbedDisplay\Easychart.
 */

namespace Drupal\easychart\Plugin\entity_embed\EntityEmbedDisplay;

use Drupal\Core\Form\FormStateInterface;
use Drupal\easychart\EasychartHelper;
use Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayBase;


/**
 * Entity Embed Display to render Easycharts.
 *
 * @see \Drupal\entity_embed\EntityEmbedDisplay\EntityEmbedDisplayInterface
 *
 * @EntityEmbedDisplay(
 *   id = "easychart",
 *   label = @Translation("Easychart"),
 * )
 */
class Easychart extends EntityEmbedDisplayBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $output = [];
    $route_match = \Drupal::routeMatch();

    // Show placeholder during preview.
    if ($route_match->getRouteName() == 'embed.preview') {
      $output = ['#markup' => '<img src="' . base_path() . drupal_get_path('module', 'easychart') . '/assets/chart-placeholder.png">'];
    }
    // Otherwise, render the chart.
    else {

      $entity = $this->getEntityFromContext();
      if (!empty($entity)) {
        $delta = 0;
        $entity_id = $entity->id();
        $values = $entity->easychart->getValue();
        if ($output = EasychartHelper::easychartPrintChart($values[0], $entity_id, $delta)) {
          $element[$delta] = array('#markup' => $output['markup']);
          $element['#attached']['drupalSettings']['easychart'][$entity_id][$delta] = array(
            'config' => $output['config'],
            'csv' => $output['csv'],
          );
        }
      }

      if (!empty($element)) {
        EasychartHelper::addRenderLibraries($element);
        $output = $element;
      }
    }

    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    return array();
  }
}
